//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Tree Item API  (starting from 5.3)
//
#define ML_IPC_TREEITEM_GETHANDLE	0x120 // Gives you HANDLE to the item with specified ID in the param
#define ML_IPC_TREEITEM_GETCHILD		0x121 // Returns HANDLE to the child item for the item HANDLE specified as a param. 
#define ML_IPC_TREEITEM_GETNEXT		0x122 // Returns HANDLE to the next item for the item HANDLE specified as a param.
#define ML_IPC_TREEITEM_GETSELECTED	0x123 // Returns HANDLE to selected item.
#define ML_IPC_TREEITEM_GETINFO		0x124 // Pass MLTREEITEMINFO as a param. return TRUE - if ok
#define ML_IPC_TREEITEM_SETINFO		0x125 // Pass MLTREEITEMINFO as a param. return TRUE - if ok
#define ML_IPC_TREEITEM_ADD			0x126 // Adds new item using MLTREEITEM passed as a param
#define ML_IPC_TREEITEM_DELETE		0x127 // Deletes tree item. Pass HANDLE as a param.
#define ML_IPC_TREEITEM_SELECT		0x128 // Selects tree item. Pass HANDLE as a param. 
#define ML_IPC_TREEITEM_GETROOT		0x129 // Gets first item.
#define ML_IPC_TREEITEM_INSERT    0x130 // like ML_IPC_TREEITEM_ADD, but id becomes an "insert after" ID
#define ML_IPC_TREEITEM_GETCHILD_ID		0x131 // Returns ID to the child item for the item ID specified as a param. 
#define ML_IPC_TREEITEM_GETNEXT_ID		0x132 // Returns ID to the next item for the item ID specified as a param.
#define ML_IPC_TREEITEM_ADDW			0x133 // Adds new item using MLTREEITEMW passed as a param
#define ML_IPC_TREEITEM_INSERTW    0x134 // like ML_IPC_TREEITEM_ADDW, but id becomes an "insert after" ID
#define MLTI_ROOT			(INT_PTR)TVI_ROOT // can be used in ML_IPC_TREEITEM_GETCHILD

typedef struct {
  size_t	size;			// size of this struct
  UINT		id;				// depends on context
  UINT		parentId;		// 0 = root, or ML_TREEVIEW_ID_*
  char		*title;			// pointer to the buffer contained item name. 
  size_t	titleLen;		// used for GetInfo 
  BOOL		hasChildren;	// TRUE - has children
  int		imageIndex;		// index of the associated image
} MLTREEITEM;

typedef struct {
  MLTREEITEM	item;	// item data
  UINT			mask;	// one or more of MLTI_* flags
  UINT_PTR		handle; // Handle to the item. If handle is NULL item->id will be used
} MLTREEITEMINFO;

typedef struct {
  size_t	size;			// size of this struct
  UINT		id;				// depends on context
  UINT		parentId;		// 0 = root, or ML_TREEVIEW_ID_*
  wchar_t	*title;			// pointer to the buffer contained item name. 
  size_t	titleLen;		// used for GetInfo 
  BOOL		hasChildren;	// TRUE - has children
  int		imageIndex;		// index of the associated image
} MLTREEITEMW;

// Flags that used in the MLTREEITEMINFO struct
#define MLTI_CHILDREN	TVIF_CHILDREN
#define MLTI_IMAGE		TVIF_IMAGE
#define MLTI_TEXT		TVIF_TEXT
#define MLTI_ID			TVIF_PARAM


//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Tree image (starting from 5.3)
// Used to add or change the image that is shown in the ML tree view.
// The idea is to create a grayscale image. gen_ml will then "color" your image with the listview colors,
// depending on the "filterProc" value in the MLTREEIMAGE struct.
// * Image must be BMP file, recommended size 16x16 pixel.
// * BMP file must be true-color (16 mio colors), not the 256 color type that is
//   created by MSVC!
// * With filterProc==FILTER_DEFAULT1, black is colored with the current background
//   color, white parts of the image are colored in the foreground color
// * With filterProc==FILTER_DEFAULT2, it's the other way round: black parts of the
//   image are colored with the current foreground color.

#define ML_IPC_TREEIMAGE_ADD 0x140 // adds tree image to the ml. Use MLTREEIMAGE as the param.

typedef struct 
{
	unsigned char rgbBlue;
	unsigned char rgbGreen;
	unsigned char rgbRed;
}COLOR24; // color struct 

typedef void (*BMPFILTERPROC)(const COLOR24*, const COLOR24*, COLOR24*); // color filter procedure 
// you got two colors: color1 and color2 (usualy BG and FG colors) also you as a third parameter
// you get a pixel color value that you need (can) modify  

#define FILTER_NO       ((BMPFILTERPROC)0)
#define FILTER_DEFAULT1 ((BMPFILTERPROC)1)
#define FILTER_DEFAULT2 ((BMPFILTERPROC)2)

#define MLTREEIMAGE_NONE					0
#define MLTREEIMAGE_DEFAULT					1
#define MLTREEIMAGE_BRANCH					2   // calculates at the time 	
#define MLTREEIMAGE_BRANCH_EXPANDED			3
#define MLTREEIMAGE_BRANCH_COLLAPSED		4
#define MLTREEIMAGE_BRANCH_NOCHILD			5

typedef struct {
	HINSTANCE				hinst;					// hInstance
	int				resourceId;				// resource id 
	int				imageIndex;				// set image to specified index (specify -1 to get a new index back)
	BMPFILTERPROC	filterProc;				// pointer to the filter proc to use or one of the FILTER_*
	int				width;					// reserved
	int				height;					// reserved
} MLTREEIMAGE;   // basicly ml will read your reosurce when it will need to create your image

#define ML_IPC_NEWPLAYLIST           0x107 // pass hwnd for dialog parent as param
#define ML_IPC_IMPORTPLAYLIST        0x108 // pass hwnd for dialog parent as param
#define ML_IPC_IMPORTCURRENTPLAYLIST 0x109
#define ML_IPC_GETPLAYLISTWND        0x10A
#define ML_IPC_SAVEPLAYLIST          0x10B // pass hwnd for dialog parent as param
#define ML_IPC_OPENPREFS             0x10C

#define ML_IPC_PLAY_PLAYLIST 0x010D // plays the playlist pointed to by the tree item passed, returns 1 if found, 0 if not
#define ML_IPC_LOAD_PLAYLIST 0x010E // loads the playlist pointed to by the tree item passed into the playlist editor, returns 1 if found, 0 if not

#define ML_IPC_REFRESH_PREFS 0x10F // this doesn't belong in here 

